@@ -1,3 +1,9 @@
+( cd opt/kde/share/doc/HTML/fi/kfind ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fi/kfind ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
+( cd opt/kde/share/doc/HTML/fi/khelpcenter/glossary ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fi/khelpcenter/glossary ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
+( cd opt/kde/share/doc/HTML/fi/khelpcenter ; rm -rf common )
+( cd opt/kde/share/doc/HTML/fi/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/fi/common common )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf fdl-license )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/fdl-license fdl-license )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf qpl-license.html )
@@ -20,6 +26,8 @@
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/6.png 6.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf 7.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/7.png 7.png )
+( cd opt/kde/share/doc/HTML/fi/common ; rm -rf top-right-konqueror.png )
+( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/top-right-konqueror.png top-right-konqueror.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf 8.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/8.png 8.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf 9.png )
@@ -50,6 +58,8 @@
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/footer.html footer.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf kde-common.css )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/kde-common.css kde-common.css )
+( cd opt/kde/share/doc/HTML/fi/common ; rm -rf bottom-left.png )
+( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/bottom-left.png bottom-left.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf appheader.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/appheader.html appheader.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf doctop1.png )
@@ -62,8 +72,12 @@
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/kde_logo.png kde_logo.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf docheadergears.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/docheadergears.png docheadergears.png )
+( cd opt/kde/share/doc/HTML/fi/common ; rm -rf top-middle.png )
+( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/top-middle.png top-middle.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf fdl-license.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/fdl-license.html fdl-license.html )
+( cd opt/kde/share/doc/HTML/fi/common ; rm -rf bottom-right.png )
+( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/bottom-right.png bottom-right.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf doctop1a.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/doctop1a.png doctop1a.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf 10.png )
@@ -80,6 +94,10 @@
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/bottom2.png bottom2.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf header.html )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/header.html header.html )
+( cd opt/kde/share/doc/HTML/fi/common ; rm -rf bottom-middle.png )
+( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/bottom-middle.png bottom-middle.png )
+( cd opt/kde/share/doc/HTML/fi/common ; rm -rf top-left.png )
+( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/top-left.png top-left.png )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf gpl-license )
 ( cd opt/kde/share/doc/HTML/fi/common ; ln -sf ../../en/common/gpl-license gpl-license )
 ( cd opt/kde/share/doc/HTML/fi/common ; rm -rf kde-localised.css.template )
